@@ -312,6 +312,17 @@ class Utils:
         object_as_json_str = json.dumps(my_object, default=lambda o: o.__dict__)
         return json.loads(object_as_json_str)
 
+    @staticmethod
+    def str_to_bool(value: str) -> bool:
+        value_l = value.lower()
+        if value_l in ['true', '1']:
+            return True
+
+        if value_l in ['false', '0']:
+            return False
+
+        raise ValueError(f'Invalid boolean value "{value}"')
+
 
 class GatewayUtils:
     """
